==> qtjambi-quick-debuginfo-macos-5.15.20.jar: sources/QtJambiQuick/QQuickItem_UpdatePaintNodeData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickitem.h>
#include <QtCore/QVariant>
#include <QtQuick/QSGTransformNode>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuickItem_UpdatePaintNodeData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuickItem::UpdatePaintNodeData")
    QQuickItem::UpdatePaintNodeData *_ptr = reinterpret_cast<QQuickItem::UpdatePaintNodeData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItem_00024UpdatePaintNodeData_setTransformNode_1native_1QSGTransformNode_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID transformNode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickItem::UpdatePaintNodeData *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItem::UpdatePaintNodeData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QSGTransformNode* __qt_transformNode0 = QtJambiAPI::objectFromNativeId<QSGTransformNode>(transformNode0);
        __qt_this->transformNode = __qt_transformNode0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItem_00024UpdatePaintNodeData_transformNode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickItem::UpdatePaintNodeData *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItem::UpdatePaintNodeData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QSGTransformNode*  __qt_value = __qt_this->transformNode;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQuickItem_UpdatePaintNodeData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QQuickItem::UpdatePaintNodeData>("QQuickItem::UpdatePaintNodeData", "io/qt/quick/QQuickItem$UpdatePaintNodeData");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuickItem_UpdatePaintNodeData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-6.6.0.jar: sources/QtJambiQuick/QQuickItem_UpdatePaintNodeData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickitem.h>
#include <QtCore/QVariant>
#include <QtQuick/QSGTransformNode>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuickItem_UpdatePaintNodeData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuickItem::UpdatePaintNodeData")
    QQuickItem::UpdatePaintNodeData *_ptr = reinterpret_cast<QQuickItem::UpdatePaintNodeData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItem_00024UpdatePaintNodeData_setTransformNode_1native_1QSGTransformNode_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID transformNode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickItem::UpdatePaintNodeData *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItem::UpdatePaintNodeData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QSGTransformNode* __qt_transformNode0 = QtJambiAPI::objectFromNativeId<QSGTransformNode>(transformNode0);
        __qt_this->transformNode = __qt_transformNode0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItem_00024UpdatePaintNodeData_transformNode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuickItem::UpdatePaintNodeData *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItem::UpdatePaintNodeData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QSGTransformNode*  __qt_value = __qt_this->transformNode;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItem_00024UpdatePaintNodeData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuickItem::UpdatePaintNodeData *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItem::UpdatePaintNodeData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QQuickItem::UpdatePaintNodeData(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuickItem_UpdatePaintNodeData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QQuickItem::UpdatePaintNodeData>("QQuickItem::UpdatePaintNodeData", "io/qt/quick/QQuickItem$UpdatePaintNodeData");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuickItem_UpdatePaintNodeData);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
